@@ -23,11 +23,13 @@
 
 
 "bgp" <-
-function(X, Z, XX=NULL, bprior="bflat", corr="expsep", BTE=c(1000,4000,3), R=1, m0r1=FALSE,
+function(X, Z, XX=NULL, bprior="bflat", corr="expsep",
+         BTE=c(1000,4000,2), R=1, m0r1=FALSE,
          pred.n=TRUE, ds2x=FALSE, ego=FALSE)
 {
 	n <- dim(X)[1]
-	if(is.null(n)) { n <- length(X); X <- matrix(X, nrow=n); d <- 1 } else { d <- dim(X)[2] }
+	if(is.null(n)) { n <- length(X); X <- matrix(X, nrow=n); d <- 1 }
+        else { d <- dim(X)[2] }
 	params <- tgp.default.params(d+1)
 	params$bprior <- bprior
 	params$corr <- corr
