@@ -349,21 +349,21 @@ unsigned int m,n;
 double **K, **DIST;
 double d, nug, phi, nu;
 {
-	int i,j;
-
-	if(d == 0.0) {
-		if(m == n && nug > 0) id(K, n);
-		else zero(K, n, m);
-	} else {
-		for(i=0; i<n; i++) 
-			for(j=0; j<m; j++) 
-			  K[i][j] = phi*pow(DIST[i][j]/d, nu);
-		          K[i][j] = K[i][j]*bessel_k(DIST[i][j]/d, nu, 1);
-			  K[i][j] = K[i][j]/(pow(2.0, nu-1)*gamma(nu)*pow(d, -2.0*nu));
-                       
-                 
-	}	
-	if(nug > 0 && m == n) for(i=0; i<m; i++) K[i][i] += nug; 
+  int i,j;
+  
+  if(d == 0.0) {
+    if(m == n && nug > 0) id(K, n);
+    else zero(K, n, m);
+  } else {
+    for(i=0; i<n; i++) {
+      for(j=0; j<m; j++) {
+	K[i][j] = phi*pow(DIST[i][j]/d, nu);
+	K[i][j] = K[i][j]*bessel_k(DIST[i][j]/d, nu, 1);
+	K[i][j] = K[i][j]/(pow(2.0, nu-1)*gammafn(nu)*pow(d, -2.0*nu));
+      }
+    }
+  }	
+  if(nug > 0 && m == n) for(i=0; i<m; i++) K[i][i] += nug; 
 }
 
 
@@ -381,21 +381,21 @@ unsigned int n;
 double **K, **DIST;
 double d, nug, phi, nu;
 {
-	int i,j;
-
-	assert(nug >= 0);
-	if(d == 0.0) id(K, n);
-	for(i=0; i<n; i++) {
-		K[i][i] = 1.0 + nug;
-		if(d == 0.0) continue;
-		for(j=i+1; j<n; j++) {
-		          K[i][j] = phi*pow(DIST[i][j]/d, nu);
-		          K[i][j] = K[i][j]*bessel_k(DIST[i][j]/d, nu, 1);
-			  K[i][j] = K[i][j]/(pow(2.0, nu-1)*gamma(nu)*pow(d, -2.0*nu));
-		       	  K[j][i] = K[i][j];
-                          if(i>130){printf("d %g \n", d);} 
-		}
-	}
+  int i,j;
+  
+  assert(nug >= 0);
+  if(d == 0.0) id(K, n);
+  for(i=0; i<n; i++) {
+    K[i][i] = 1.0 + nug;
+    if(d == 0.0) continue;
+    for(j=i+1; j<n; j++) {
+      K[i][j] = phi*pow(DIST[i][j]/d, nu);
+      K[i][j] = K[i][j]*bessel_k(DIST[i][j]/d, nu, 1);
+      K[i][j] = K[i][j]/(pow(2.0, nu-1)*gammafn(nu)*pow(d, -2.0*nu));
+      K[j][i] = K[i][j];
+      if(i>130){printf("d %g \n", d);} 
+    }
+  }
 }
 
 
